@@ -21,13 +21,14 @@ from cgdb.managers import StationGroupsManager
 from cgdb.managers import LevelsManager
 
 from cgdb.utils import CGDBAPISession
+import cgdb.config
 import urllib3
 urllib3.disable_warnings()
 
 class CGDB:
     """Client class for communication with CGDB
     """
-    def __init__(self, api_key, host=None):
+    def __init__(self, api_key, host=None, debug=False):
         """ :type api_key: str
             :param api_key: api key for authenticate to api endpoint
 
@@ -50,6 +51,7 @@ class CGDB:
         self._aggregations_manager = AggregationsManager()
         self._station_groups_manager = StationGroupsManager(client=self)
         self._levels_manager = LevelsManager(client=self)
+        cgdb.config.DEBUG_CONSOLE_LOG_CGDB_LIB = debug
 
 
     def sites(self):
