@@ -31,7 +31,7 @@ def _json_values_to_dataframe(values, mapping_flags, mapping_params, data_set: D
         return pd.DataFrame({"datetime": [], "value": []})
 
     data_page = pd.DataFrame(records)
-    data_page["timestamp"] = data_page["timestamp"]+3600
+    data_page["timestamp"] = data_page["timestamp"]+7200
     data_page["timestamp"] = pd.to_datetime(data_page['timestamp'], unit="s", )
     # data_page.timestamp = data_page.timestamp.dt.tz_localize('Europe/Brussels')
     data_page.rename(columns={"timestamp": "datetime", "value": data_set.code}, inplace=True)
@@ -137,14 +137,13 @@ class DataSetsManager(ManagerMix):
         url = f"{data_set.url}/data"
 
         if date_from is not None and date_to is not None:
-
             date_from = int(datetime
                             .strptime(date_from, "%Y-%m-%d %H:%M")
-                            .replace(tzinfo=pytz.timezone("UTC")).timestamp()) - 3600
+                            .replace(tzinfo=pytz.timezone("UTC")).timestamp()) - 3600*2
             # date_from = date_from - (date_from % 300)
             date_to = int(datetime
                           .strptime(date_to, "%Y-%m-%d %H:%M")
-                          .replace(tzinfo=pytz.timezone("UTC")).timestamp()) - 3600
+                          .replace(tzinfo=pytz.timezone("UTC")).timestamp()) - 3600*2
             # date_to = date_to - (date_to % 300)
 
             url_param = f"?date-time-from={date_from}&page-size=10000"
@@ -173,7 +172,7 @@ class DataSetsManager(ManagerMix):
             values = content["values"]
 
             data_tmp = _json_values_to_dataframe(values, mapping_flags, mapping_params, data_set)
-            items_count_loaded = data.shape[0]
+            items_count_loaded = data_tmp.shape[0]
             items_count_loaded_left = items_count_loaded_left - items_count_loaded
 
             data = pd.concat([data, data_tmp])
@@ -244,7 +243,7 @@ class DataSetsManager(ManagerMix):
 
         if is_datetime(data["date_time"]):
             data['date_time'] = data.date_time.dt.tz_localize(tz="UTC")
-            data["date_time"] = (data.date_time.values.astype(np.int64) / 10 ** 9).astype(np.int64) - 3600
+            data["date_time"] = (data.date_time.values.astype(np.int64) / 10 ** 9).astype(np.int64) - 7200
 
         out = []
         for index, row in data.iterrows():
