@@ -1,5 +1,5 @@
 from cgdb.resources.aggregation import Aggregation
-from cgdb.resources.dataSet import DataSets
+from cgdb.resources.dataSet import DataSet
 
 from cgdb.resources.department import Department
 from cgdb.resources.element import Element
